#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MONEO_6_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MONEO_6_HPP_INCLUDED

#include <boost/simd/constant/include/constants/moneo_6.hpp>

#endif
